@@ -1,4 +1,4 @@
-## Copyright (C) 2009 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2009 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -11,8 +11,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 function __bw_computing_machine__ (f)
 
@@ -22,7 +21,7 @@ function __bw_computing_machine__ (f)
 
     try
       if (ismatrix (arg = __bw_prcv__ (stdin)))
-	exit (0);
+        exit (0);
       endif
     catch
       exit (0);
@@ -30,7 +29,7 @@ function __bw_computing_machine__ (f)
     arg = arg.psend_var;
     try
       if (ismatrix (arg_id = __bw_prcv__ (stdin)))
-	exit (0);
+        exit (0);
       endif
     catch
       exit (0);
