@@ -1,4 +1,4 @@
-## Copyright (C) 2009 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2009 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -11,8 +11,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 function __bw_scheduler__ (f, argfile)
 
@@ -105,25 +104,25 @@ function __bw_scheduler__ (f, argfile)
 
   ## initialize machine information
   m_n = length (computing_machines);
-  m_njobs = m_irresponsive = m_active = pids = pipesr = \
+  m_njobs = m_irresponsive = m_active = pids = pipesr = ...
       pipesw = m_just_tried = zeros (m_n, 1);
 
   ## fork one permanent subprocess per machine
   cmd = "ssh";
-  ssh_timeout_opt_str = sprintf ("-o ConnectTimeout=%i", \
-				 max (round (connect_timeout), 0));
+  ssh_timeout_opt_str = sprintf ("-o ConnectTimeout=%i", ...
+                                 max (round (connect_timeout), 0));
   for id = 1:m_n
     [pdrp, pdwc, err, msg] = pipe ();
     if (err)
-      state.scheduler_msg = \
-	  sprintf ("error %i in creating pipe, msg: %s\n", err, msg);
+      state.scheduler_msg = ...
+          sprintf ("error %i in creating pipe, msg: %s\n", err, msg);
       __bw_secure_save__ (stfn, state, "state");
       return;
     endif
     [pdrc, pdwp, err, msg] = pipe ();
     if (err)
-      state.scheduler_msg = \
-	  sprintf ("error %i in creating pipe, msg: %s\n", err, msg);
+      state.scheduler_msg = ...
+          sprintf ("error %i in creating pipe, msg: %s\n", err, msg);
       __bw_secure_save__ (stfn, state, "state");
       return;
     endif
@@ -133,71 +132,71 @@ function __bw_scheduler__ (f, argfile)
       pclose (pdwp);
       fcntl (pdrc, F_SETFL, O_SYNC);
       while (true) # no break, process killed from parent process
-	cmd_args = {"-o PasswordAuthentication=no", \
-		    ssh_timeout_opt_str, \
-		    computing_machines{id}, \
-		    "octave", \
-		    "-q", \
-		    "--eval", \
-		    (sprintf \
-		     ("\"__bw_computing_machine__ (\\\"%s\\\")\"", \
-		      f)), \
-		    "2>/dev/null"};
-	constart = time;
-	[pdw, pdr, pid] = popen2 (cmd, cmd_args, 1);
-	while (true) # break if eof on pdr
-	  arg_id = __bw_prcv__ (pdrc).psend_var;
-	  __bw_psend__ (pdw, args{arg_id});
-	  __bw_psend__ (pdw, arg_id);
-	  fflush (pdw);
-	  try
-	    if (ismatrix (tp = __bw_prcv__ (pdr)))
-	      break;
-	    endif
-	  catch
-	    break;
-	  end_try_catch
-	  tp = tp.psend_var;
-	  if (tp == 2) # computing function returned error
-	    try
-	      if (ismatrix (tp = __bw_prcv__ (pdr)))
-		break;
-	      endif
-	    catch
-	      break;
-	    end_try_catch
-	    tp = tp.psend_var;
-	    __bw_psend__ (pdwc, 2);
-	    __bw_psend__ (pdwc, tp);
-	    fflush (pdwc);
-	  else # success
-	    try
-	      if (ismatrix (tp = __bw_prcv__ (pdr)))
-		break;
-	      endif
-	    catch
-	      break;
-	    end_try_catch
-	    tp = tp.psend_var;
-	    __bw_psend__ (pdwc, 0);
-	    __bw_psend__ (pdwc, tp);
-	    fflush (pdwc);
-	  endif
-	endwhile
-	waitpid (pid);
-	pclose (pdr);
-	pclose (pdw);
-	__bw_psend__ (pdwc, 1); # computing machine (got) unreachable
-	fflush (pdwc);
-	if ((rest = connect_timeout + constart - time) > 0)
-	  pause (rest);
-	endif
+        cmd_args = {"-o PasswordAuthentication=no", ...
+                    ssh_timeout_opt_str, ...
+                    computing_machines{id}, ...
+                    "octave", ...
+                    "-q", ...
+                    "--eval", ...
+                    (sprintf ...
+                     ("\"__bw_computing_machine__ (\\\"%s\\\")\"", ...
+                      f)), ...
+                    "2>/dev/null"};
+        constart = time;
+        [pdw, pdr, pid] = popen2 (cmd, cmd_args, 1);
+        while (true) # break if eof on pdr
+          arg_id = __bw_prcv__ (pdrc).psend_var;
+          __bw_psend__ (pdw, args{arg_id});
+          __bw_psend__ (pdw, arg_id);
+          fflush (pdw);
+          try
+            if (ismatrix (tp = __bw_prcv__ (pdr)))
+              break;
+            endif
+          catch
+            break;
+          end_try_catch
+          tp = tp.psend_var;
+          if (tp == 2) # computing function returned error
+            try
+              if (ismatrix (tp = __bw_prcv__ (pdr)))
+                break;
+              endif
+            catch
+              break;
+            end_try_catch
+            tp = tp.psend_var;
+            __bw_psend__ (pdwc, 2);
+            __bw_psend__ (pdwc, tp);
+            fflush (pdwc);
+          else # success
+            try
+              if (ismatrix (tp = __bw_prcv__ (pdr)))
+                break;
+              endif
+            catch
+              break;
+            end_try_catch
+            tp = tp.psend_var;
+            __bw_psend__ (pdwc, 0);
+            __bw_psend__ (pdwc, tp);
+            fflush (pdwc);
+          endif
+        endwhile
+        waitpid (pid);
+        pclose (pdr);
+        pclose (pdw);
+        __bw_psend__ (pdwc, 1); # computing machine (got) unreachable
+        fflush (pdwc);
+        if ((rest = connect_timeout + constart - time) > 0)
+          pause (rest);
+        endif
       endwhile
 
       ## not reached, but left here lest they are needed sometime
       pclose (pdrc);
       pclose (pdwc);
-      __internal_exit__ (0);
+      __exit__ (0);
     elseif (pids(id) > 0) # parent process
       pclose (pdwc);
       pclose (pdrc);
@@ -205,8 +204,8 @@ function __bw_scheduler__ (f, argfile)
       pipesw(id) = pdwp;
       fcntl (pipesr(id), F_SETFL, O_SYNC);
     else # error
-      state.scheduler_msg = \
-	  sprintf ("error %i in forking, msg: %s\n", pids(id), msg);
+      state.scheduler_msg = ...
+          sprintf ("error %i in forking, msg: %s\n", pids(id), msg);
       __bw_secure_save__ (stfn, state, "state");
       return;
     endif    
@@ -217,11 +216,11 @@ function __bw_scheduler__ (f, argfile)
 
   while (! all (state.ready))
     args_unused = find (! (state.ready | state.active));
-    m_free = cat (1, \
-		  find (! (m_active | m_irresponsive)), \
-		  find ((! (m_active | m_just_tried)) & \
-			m_irresponsive), \
-		  find ((! m_active) & m_just_tried & m_irresponsive));
+    m_free = cat (1, ...
+                  find (! (m_active | m_irresponsive)), ...
+                  find ((! (m_active | m_just_tried)) & ...
+                        m_irresponsive), ...
+                  find ((! m_active) & m_just_tried & m_irresponsive));
     ## there should always be free childs here, give them a task
     for id = 1:min (length (m_free), length (args_unused))
       ## tell child to use this argument
@@ -238,57 +237,57 @@ function __bw_scheduler__ (f, argfile)
     ## respond to childs answers
     for id = act_idx
       try
-	res = __bw_prcv__ (pipesr(id)).psend_var;
+        res = __bw_prcv__ (pipesr(id)).psend_var;
       catch
-	state.scheduler_msg = \
-	    sprintf ("error in reading state from child %i\n", id);
-	__bw_secure_save__ (stfn, state, "state");
-	return;
+        state.scheduler_msg = ...
+            sprintf ("error in reading state from child %i\n", id);
+        __bw_secure_save__ (stfn, state, "state");
+        return;
       end_try_catch
       switch res
-	case 0 # success
-	  m_irresponsive(id) = false;
-	  m_just_tried(id) = false;
-	  m_njobs(id)++;
-	  state.active(m_active(id)) = false;
-	  state.ready(m_active(id)) = true;
-	  try
-	    state.results{m_active(id)} = __bw_prcv__ (pipesr(id)).psend_var;
-	  catch
-	    state.scheduler_msg = \
-		sprintf ("error in reading result %i from child %i\n", \
-			 m_active(id), id);
-	    __bw_secure_save__ (stfn, state, "state");
-	    return;
-	  end_try_catch
-	  m_active(id) = 0;
-	case 1 # computing machine (got) unreachable
-	  state.active(m_active(id)) = false;
-	  m_irresponsive(id) = true;
-	  m_just_tried(id) = true;
-	  m_active(id) = 0;
-	case 2 # computing function returned error
-	  m_irresponsive(id) = false;
-	  m_just_tried(id) = false;
-	  m_njobs(id)++;
-	  state.active(m_active(id)) = false;
-	  state.ready(m_active(id)) = true;
-	  state.error(m_active(id)) = true;
-	  try
-	    state.msg{m_active(id)} = __bw_prcv__ (pipesr(id)).psend_var;
-	  catch
-	    state.scheduler_msg = \
-		sprintf ("error in reading functions error message for args %i from child %i\n", \
-			 m_active(id), id);
-	    __bw_secure_save__ (stfn, state, "state");
-	    return;
-	  end_try_catch
-	  m_active(id) = 0;
-	otherwise # invalid
-	  state.scheduler_msg = \
-	      sprintf ("child %i returned invalid state\n", res);
-	  __bw_secure_save__ (stfn, state, "state");
-	  return;
+        case 0 # success
+          m_irresponsive(id) = false;
+          m_just_tried(id) = false;
+          m_njobs(id)++;
+          state.active(m_active(id)) = false;
+          state.ready(m_active(id)) = true;
+          try
+            state.results{m_active(id)} = __bw_prcv__ (pipesr(id)).psend_var;
+          catch
+            state.scheduler_msg = ...
+                sprintf ("error in reading result %i from child %i\n", ...
+                         m_active(id), id);
+            __bw_secure_save__ (stfn, state, "state");
+            return;
+          end_try_catch
+          m_active(id) = 0;
+        case 1 # computing machine (got) unreachable
+          state.active(m_active(id)) = false;
+          m_irresponsive(id) = true;
+          m_just_tried(id) = true;
+          m_active(id) = 0;
+        case 2 # computing function returned error
+          m_irresponsive(id) = false;
+          m_just_tried(id) = false;
+          m_njobs(id)++;
+          state.active(m_active(id)) = false;
+          state.ready(m_active(id)) = true;
+          state.error(m_active(id)) = true;
+          try
+            state.msg{m_active(id)} = __bw_prcv__ (pipesr(id)).psend_var;
+          catch
+            state.scheduler_msg = ...
+                sprintf ("error in reading functions error message for args %i from child %i\n", ...
+                         m_active(id), id);
+            __bw_secure_save__ (stfn, state, "state");
+            return;
+          end_try_catch
+          m_active(id) = 0;
+        otherwise # invalid
+          state.scheduler_msg = ...
+              sprintf ("child %i returned invalid state\n", res);
+          __bw_secure_save__ (stfn, state, "state");
+          return;
       endswitch
     endfor
     ## update statefile, but not if last update was a short time ago
