@@ -1,4 +1,4 @@
-## Copyright (C) 2010 Olaf Till <olaf.till@uni-jena.de>
+## Copyright (C) 2010, 2013 Olaf Till <i7tiol@t-online.de>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -11,8 +11,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 function __pserver_exit__ (hn)
 
