@@ -1,6 +1,6 @@
-// Copyright (C) 2002 Hayato Fujiwara
+// Copyright (C) 2002 Hayato Fujiwara <h_fujiwara@users.sourceforge.net>
 
-// Copyright (C) 2010, 2011 Olaf Till <olaf.till@uni-jena.de>
+// Copyright (C) 2010-2013 Olaf Till <i7tiol@t-online.de>
 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -13,8 +13,7 @@
 // GNU General Public License for more details.
 
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #include <octave/oct.h>
 #include <octave/load-save.h>
@@ -27,10 +26,15 @@
 #include <netinet/in.h>
 #include <netdb.h>
 
+#if HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
-DEFUN_DLD (recv, args, nargout, "recv (socket)\n\
-\n\
-Receive a variable from the computer specified by the row vector 'socket'.\n")
+DEFUN_DLD (recv, args, nargout,
+           "-*- texinfo -*-\n\
+@deftypefn {Loadable Function} recv (socket)\n\
+Receive a variable from the computer specified by the row vector 'socket'.\n\
+@end deftypefn")
 {
   octave_value retval;
 
@@ -55,54 +59,42 @@ Receive a variable from the computer specified by the row vector 'socket'.\n")
       sock = (int) socket.data ()[1];
       spollfd.fd = sock;
       spollfd.events = POLLIN;
-	
+        
       num = poll (&spollfd, 1, 0);
       if (num)
-	{
-	  if (spollfd.revents && (spollfd.fd !=0))
-	    {
-	      sockaddr_in r_addr;
-	      struct hostent *hehe;
-	      socklen_t len = sizeof (r_addr);
-	      getpeername (spollfd.fd, (sockaddr*)&r_addr, &len);
-	      hehe = gethostbyaddr ((char *)&r_addr.sin_addr.s_addr,
-				    sizeof(r_addr.sin_addr), AF_INET);
+        {
+          if (spollfd.revents && (spollfd.fd !=0))
+            {
+              sockaddr_in r_addr;
+              struct hostent *hehe;
+              socklen_t len = sizeof (r_addr);
+              getpeername (spollfd.fd, (sockaddr*) &r_addr, &len);
+              hehe = gethostbyaddr ((char *) &r_addr.sin_addr.s_addr,
+                                    sizeof (r_addr.sin_addr), AF_INET);
 
-	      if (spollfd.revents & POLLIN)
-		{
-		  pid = getpid ();
-		  if (read (spollfd.fd, &nl, sizeof (int)) <
-		      sizeof (int))
-		    {
-		      error ("read error");
-		    }
-		  error_code = ntohl (nl);
-		  if (write (spollfd.fd, &nl, sizeof (int)) <
-		      sizeof (int))
-		    {
-		      error ("write error");
-		    }
-		  error ("error occurred in %s\n\tsee "
-			 "%s:/tmp/octave_error-%s_%5d.log for detail",
-			 hehe->h_name, hehe->h_name, hehe->h_name, pid);
-		}
-	      if (spollfd.revents & POLLERR)
-		{
-		  error ("Error condition - %s", hehe->h_name);
-		}
-	      if (spollfd.revents & POLLHUP)
-		{
-		  error("Hung up - %s", hehe->h_name);
-		}
-	      if (spollfd.revents & POLLNVAL)
-		{
-		  error("fd not open - %s", hehe->h_name);
-		}
-	    }
-	}
+              if (spollfd.revents & POLLIN)
+                {
+                  pid = getpid ();
+                  if (read (spollfd.fd, &nl, sizeof (int)) < sizeof (int))
+                    error ("read error");
+                  error_code = ntohl (nl);
+                  if (write (spollfd.fd, &nl, sizeof (int)) < sizeof (int))
+                    error ("write error");
+                  error ("error occurred in %s\n\tsee "
+                         "%s:/tmp/octave_error-%s_%5d.log for detail",
+                         hehe->h_name, hehe->h_name, hehe->h_name, pid);
+                }
+              if (spollfd.revents & POLLERR)
+                error ("Error condition - %s", hehe->h_name);
+              if (spollfd.revents & POLLHUP)
+                error("Hung up - %s", hehe->h_name);
+              if (spollfd.revents & POLLNVAL)
+                error("fd not open - %s", hehe->h_name);
+            }
+        }
 
       if (error_state)
-	return retval;
+        return retval;
     }
 
 
